@@ -1,11 +1,8 @@
 context("ggfacet")
 
-expect_print <- function(p) {
-  testthat::expect_silent(print(p, progress = FALSE))
-}
+skip_if_not_installed("chemometrics")
 
-suppressMessages(library(chemometrics, quietly = TRUE))
-data(NIR)
+data(NIR, package = "chemometrics")
 NIR_sub <- data.frame(NIR$yGlcEtOH, NIR$xNIR[, 1:3])
 
 test_that("warnings", {
@@ -21,17 +18,17 @@ test_that("warnings", {
 
 test_that("generally works", {
   # factor variables
-  expect_print(ggfacet(NIR_sub, columnsY = 1:2, columnsX = 3:5, fn = ggally_smooth_loess))
-
-})
-
-test_that("generally works", {
-  # factor variables
-  expect_print(ggfacet(NIR_sub, columnsY = 1:2, columnsX = 3:5, fn = ggally_smooth_loess))
-
-
-  expect_print(
-    ggts(pigs, "time", c("gilts", "profit", "s_per_herdsz", "production", "herdsz"))
+  vdiffr::expect_doppelganger(
+    "factor",
+    ggfacet(
+      NIR_sub,
+      columnsY = 1:2, columnsX = 3:5,
+      fn = ggally_smooth_loess
+    )
   )
 
+  vdiffr::expect_doppelganger(
+    "pigs",
+    ggts(pigs, "time", c("gilts", "profit", "s_per_herdsz", "production", "herdsz"))
+  )
 })
