@@ -1,21 +1,10 @@
-
-
 context("gglegend")
-
-expect_print <- function(p, ...) {
-  testthat::expect_silent(print(p))
-}
+library(ggplot2)
 
 test_that("examples", {
-  library(ggplot2)
-
-  histPlot <- qplot(
-    x = Sepal.Length,
-    data = iris,
-    fill = Species,
-    geom = "histogram",
-    binwidth = 1 / 4
-  )
+  histPlot <-
+    ggplot(diamonds, aes(price, fill = cut)) +
+    geom_histogram(binwidth = 500)
 
   (right <- histPlot)
   (bottom <- histPlot + theme(legend.position = "bottom"))
@@ -23,34 +12,35 @@ test_that("examples", {
   (left <- histPlot + theme(legend.position = "left"))
 
 
-  expect_legend <- function(p) {
+  expect_legend <- function(name, p) {
     plotLegend <- grab_legend(p)
     expect_true(inherits(plotLegend, "gtable"))
     expect_true(inherits(plotLegend, "gTree"))
     expect_true(inherits(plotLegend, "grob"))
-    expect_print(plotLegend)
+    vdiffr::expect_doppelganger(paste0("pos-", name), plotLegend)
   }
 
-  expect_legend(right)
-  expect_legend(bottom)
-  expect_legend(top)
-  expect_legend(left)
-
+  expect_legend("right", right)
+  expect_legend("bottom", bottom)
+  expect_legend("top", top)
+  expect_legend("left", left)
 })
 
 
 test_that("legend", {
-
   # display regular plot
-  expect_print(
+  vdiffr::expect_doppelganger(
+    "legend",
     ggally_points(iris, ggplot2::aes(Sepal.Length, Sepal.Width, color = Species))
   )
 
   # Make a function that will only print the legend
   points_legend <- gglegend(ggally_points)
-  expect_print(points_legend(
+  l <- points_legend(
     iris, ggplot2::aes(Sepal.Length, Sepal.Width, color = Species)
-  ))
+  )
+  vdiffr::expect_doppelganger("points", l)
+
 
   # produce the sample legend plot, but supply a string that 'wrap' understands
   same_points_legend <- gglegend("points")
@@ -64,7 +54,7 @@ test_that("legend", {
   p <- custom_legend(
     iris, ggplot2::aes(Sepal.Length, Sepal.Width, color = Species)
   )
-  expect_print(p)
+  vdiffr::expect_doppelganger("custom", p)
   expect_true(inherits(p, "gtable"))
   expect_true(inherits(p, "gTree"))
   expect_true(inherits(p, "grob"))
@@ -72,31 +62,38 @@ test_that("legend", {
   # Use within ggpairs
   expect_silent({
     pm <- ggpairs(
-     iris, 1:2,
-     mapping = ggplot2::aes(color = Species),
-     upper = list(continuous = gglegend("points"))
+      iris, 1:2,
+      mapping = ggplot2::aes(color = Species),
+      upper = list(continuous = gglegend("points"))
     )
-    print(pm)
   })
+  vdiffr::expect_doppelganger("legend-pm", pm)
 
   # Use within ggpairs
   expect_silent({
     pm <- ggpairs(
-     iris, 1:2,
-     mapping = ggplot2::aes(color = Species)
+      iris, 1:2,
+      mapping = ggplot2::aes(color = Species)
     )
     pm[1, 2] <- points_legend(iris, ggplot2::aes(Sepal.Width, Sepal.Length, color = Species))
-    print(pm)
   })
-
+  vdiffr::expect_doppelganger("internal-legend", pm)
 })
 
 test_that("plotNew", {
   points_legend <- gglegend(ggally_points)
-  expect_print(points_legend(
-    iris, ggplot2::aes(Sepal.Length, Sepal.Width, color = Species)
-  ))
-  expect_print(points_legend(
-    iris, ggplot2::aes(Sepal.Length, Sepal.Width, color = Species)
-), plotNew = TRUE)
+  vdiffr::expect_doppelganger(
+    "plotNew-default",
+    points_legend(
+      iris, ggplot2::aes(Sepal.Length, Sepal.Width, color = Species)
+    )
+  )
+  expect_silent(
+    print(
+      points_legend(
+        iris, ggplot2::aes(Sepal.Length, Sepal.Width, color = Species)
+      ),
+      plotNew = TRUE
+    )
+  )
 })
