@@ -1,10 +1,8 @@
-
 context("ggmatrix_add")
 
-data(tips, package = "reshape")
+data(tips)
 
 test_that("add", {
-
   pm <- ggpairs(tips)
 
   expect_true(is.null(pm$title))
@@ -19,11 +17,11 @@ test_that("add", {
 
   # first add
   pm2 <- pm + ggplot2::theme_bw()
-  expect_true(! is.null(pm2$gg))
+  expect_true(!is.null(pm2$gg))
 
   # second to nth add
   pm3 <- pm + ggplot2::theme_bw()
-  expect_true(! is.null(pm3$gg))
+  expect_true(!is.null(pm3$gg))
 
   # bad add
   expect_error(pm + 3, "'ggmatrix' does not know how to add")
@@ -37,12 +35,10 @@ test_that("add", {
   pm5 <- add_to_ggmatrix(pm, ggplot2::coord_equal(), cols = 1)
   expect_false(identical(pm$plots[[1]], pm5$plots[[1]]))
   expect_true(identical(pm$plots[[2]], pm5$plots[[2]]))
-
 })
 
 
 test_that("add_list", {
-
   pm <- ggpairs(tips, 1:2)
 
   pm1 <- pm + list(
@@ -52,16 +48,13 @@ test_that("add_list", {
 
   expect_equal(pm1$xlab, "x title")
   expect_equal(pm1$title, "list title")
-
 })
 
 test_that("v1_ggmatrix_theme", {
-
   pm <- ggpairs(tips, 1:2)
 
   pm1 <- pm + v1_ggmatrix_theme()
 
   expect_true(is.null(pm$gg))
   expect_true(!is.null(pm1$gg))
-
 })
