@@ -1,4 +1,3 @@
-
 context("ggnet")
 
 if ("package:igraph" %in% search()) {
@@ -9,25 +8,25 @@ rq <- function(...) {
   suppressMessages(require(..., quietly = TRUE))
 }
 rq(network) # network objects
-rq(sna)     # placement and centrality
+rq(sna) # placement and centrality
 
 rq(ggplot2) # grammar of graphics
-rq(grid)    # arrows
-rq(scales)  # sizing
+rq(grid) # arrows
+rq(scales) # sizing
 
 rq(intergraph) # test igraph conversion
 
 test_that("examples", {
-
   ### --- start: documented examples
+  set.seed(54321)
 
   # random adjacency matrix
-  x           <- 10
-  ndyads      <- x * (x - 1)
-  density     <- x / ndyads
-  m           <- matrix(0, nrow = x, ncol = x)
-  dimnames(m) <- list(letters[ 1:x ], letters[ 1:x ])
-  m[ row(m) != col(m) ] <- runif(ndyads) < density
+  x <- 10
+  ndyads <- x * (x - 1)
+  density <- x / ndyads
+  m <- matrix(0, nrow = x, ncol = x)
+  dimnames(m) <- list(letters[1:x], letters[1:x])
+  m[row(m) != col(m)] <- runif(ndyads) < density
   m
 
   # random undirected network
@@ -37,7 +36,7 @@ test_that("examples", {
   ggnet(n, label = TRUE, alpha = 1, color = "white", segment.color = "black")
 
   # random groups
-  g <- sample(letters[ 1:3 ], 10, replace = TRUE)
+  g <- sample(letters[1:3], 10, replace = TRUE)
 
   # color palette
   p <- c("a" = "steelblue", "b" = "forestgreen", "c" = "tomato")
@@ -71,18 +70,18 @@ test_that("examples", {
   # test trim.labels
   expect_warning(ggnet(n, trim.labels = TRUE))
 
-#   # test subset.threshold by removing all nodes
-#   expect_warning(
-#     expect_error(
-#       ggnet(n, subset.threshold = 11),
-#       "NA/NaN/Inf"
-#     ),
-#     "NaNs produced"
-#   )
-#
-#   p <- ggnet(n, mode = "geo")
-#   expect_equal(p$data$X1, xy[, 1])
-#   expect_equal(p$data$X2, xy[, 2])
+  #   # test subset.threshold by removing all nodes
+  #   expect_warning(
+  #     expect_error(
+  #       ggnet(n, subset.threshold = 11),
+  #       "NA/NaN/Inf"
+  #     ),
+  #     "NaNs produced"
+  #   )
+  #
+  #   p <- ggnet(n, mode = "geo")
+  #   expect_equal(p$data$X1, xy[, 1])
+  #   expect_equal(p$data$X2, xy[, 2])
 
   # test user-submitted weights
   ggnet(n, weight = sample(1:2, 10, replace = TRUE))
@@ -90,8 +89,8 @@ test_that("examples", {
   # test segment.label
   x <- sample(letters, network.edgecount(n))
   p <- ggnet(n, segment.label = x)
-  expect_true(p$layers[[2]]$mapping$x == "midX")
-  expect_true(p$layers[[2]]$mapping$y == "midY")
+  expect_true(mapping_string(p$layers[[2]]$mapping$x) == "midX")
+  expect_true(mapping_string(p$layers[[2]]$mapping$y) == "midY")
 
   # test weight.cut
   n %v% "weights" <- 1:10
@@ -178,9 +177,9 @@ test_that("examples", {
 
   ### --- test node labels and label sizes
 
-  ggnet(n, label = letters[ 1:10 ], color = "white")
+  ggnet(n, label = letters[1:10], color = "white")
   ggnet(n, label = "abc", color = "white", label.size = 4, size = 12)
-  expect_error(ggnet(n, label = letters[ 1:10 ], label.size = "abc"), "incorrect label.size")
+  expect_error(ggnet(n, label = letters[1:10], label.size = "abc"), "incorrect label.size")
 
   ### --- test node placement
 
@@ -200,18 +199,18 @@ test_that("examples", {
 
   # weighted adjacency matrix
   bip <- data.frame(
-    event1 = c(1, 2, 1, 0),
-    event2 = c(0, 0, 3, 0),
-    event3 = c(1, 1, 0, 4),
-    row.names = letters[1:4]
+    event1 = c(1, 2, 1),
+    event2 = c(0, 0, 3),
+    event3 = c(1, 1, 0),
+    row.names = letters[1:3]
   )
 
   # weighted bipartite network
   bip <- network(
     bip,
     matrix.type = "bipartite",
-    ignore.eval = FALSE,
-    names.eval = "weights"
+    ignore.eval = FALSE
+    # names.eval = "weights"
   )
 
   # test bipartite mode
@@ -222,7 +221,7 @@ test_that("examples", {
   expect_warning(ggnet(network(matrix(1, nrow = 2, ncol = 2), loops = TRUE)), "self-loops")
 
   expect_error(ggnet(1:2), "network object")
-  expect_error(ggnet(network(data.frame(1:2, 3:4), hyper = TRUE)), "hyper graphs")
+  expect_error(ggnet(network(data.frame(1:2, 3:4), hyper = TRUE)), "hyper")
   expect_error(ggnet(network(data.frame(1:2, 3:4), multiple = TRUE)), "multiplex graphs")
 
   ### --- test igraph functionality
@@ -237,5 +236,4 @@ test_that("examples", {
     ggnet(n, weight = "degree")
     expect_true(TRUE)
   }
-
 })
